@@ -37,7 +37,7 @@ written in .ini files. The mapping between the Python setting and the [section/o
 """
 import os
 
-from df_config.guesses.djt import guess_djt_panels
+from django import VERSION as django_version
 from django.utils.translation import gettext_lazy as _
 
 # ######################################################################################################################
@@ -53,46 +53,53 @@ from df_config.config.dynamic_settings import (
     Path,
     SettingReference,
 )
+from df_config.config.url import DatabaseURL, RedisURL, URLSetting
 from df_config.guesses.apps import allauth_provider_apps, installed_apps, middlewares
 from df_config.guesses.auth import (
+    CookieName,
     authentication_backends,
     ldap_attribute_map,
     ldap_boolean_attribute_map,
     ldap_group_class,
     ldap_group_search,
     ldap_user_search,
-    CookieName,
 )
 from df_config.guesses.databases import (
     cache_redis_url,
     cache_setting,
     celery_broker_url,
+    celery_result_url,
     databases,
     session_redis_dict,
+    websocket_redis_channels,
     websocket_redis_dict,
-    websocket_redis_channels, celery_result_url,
 )
+from df_config.guesses.djt import guess_djt_panels
 from df_config.guesses.log import log_configuration
 from df_config.guesses.misc import (
-    DefaultListenAddress,
+    AutocreateSecretKey,
     allowed_hosts,
-    csrf_trusted_origins, excluded_django_commands,
+    csp_connect,
+    csrf_trusted_origins,
+    excluded_django_commands,
+    get_asgi_application,
+    get_command_name,
+    get_hostname,
+    get_wsgi_application,
     project_name,
     required_packages,
     secure_hsts_seconds,
-    smart_hostname,
+    smart_base_url,
+    smart_listen_address,
     template_setting,
     url_parse_prefix,
     url_parse_server_name,
     url_parse_server_port,
     url_parse_server_protocol,
     url_parse_ssl,
-    use_x_forwarded_for,
-    AutocreateSecretKey,
-    get_asgi_application,
-    get_wsgi_application,
     use_sentry,
-    web_server, csp_connect,
+    use_x_forwarded_for,
+    web_server,
 )
 from df_config.guesses.pipeline import (
     pipeline_compilers,
@@ -191,7 +198,8 @@ TEMPLATE_CONTEXT_PROCESSORS = [
 TEST_RUNNER = "django.test.runner.DiscoverRunner"
 
 USE_I18N = True
-USE_L10N = True
+if django_version[0] < 4:
+    USE_L10N = True
 USE_THOUSAND_SEPARATOR = True
 USE_TZ = True
 USE_X_FORWARDED_HOST = True  # X-Forwarded-Host
@@ -422,7 +430,6 @@ CSP_BLOCK_ALL_MIXED_CONTENT = True
 DF_CSS = []
 DF_JS = []
 DF_INDEX_VIEW = None
-DF_SITE_SEARCH_VIEW = None  # 'djangofloor.views.search.UserSearchView'
 DF_PROJECT_NAME = CallableSetting(project_name)
 DF_URL_CONF = "{DF_MODULE_NAME}.urls.urlpatterns"
 DF_ADMIN_SITE = "django.contrib.admin.site"
@@ -445,6 +452,7 @@ NPM_FILE_PATTERNS = {
 }
 # used by the "npm" command: downloads these packages and copies the files matching any pattern in the list
 LOG_REMOTE_ACCESS = True
+LOG_SLOW_QUERY_DURATION_IN_S = 10.0
 LOG_DIRECTORY = Directory("{LOCAL_PATH}/log")
 LOG_EXCLUDED_COMMANDS = {
     "clearsessions",
@@ -479,6 +487,8 @@ LOG_EXCLUDED_COMMANDS = {
     "test",
     "testserver",
 }
+LOG_REMOTE_URL = None  # aliased in settings.ini as "[global]log_remote_url"
+LOG_LEVEL = None
 
 # ######################################################################################################################
 #
@@ -487,67 +497,65 @@ LOG_EXCLUDED_COMMANDS = {
 #
 # ######################################################################################################################
 ADMIN_EMAIL = "admin@{SERVER_NAME}"  # aliased in settings.ini as "[global]admin_email"
-DATABASE_ENGINE = "sqlite3"  # aliased in settings.ini as "[database]engine"
-DATABASE_NAME = Path(
-    "{LOCAL_PATH}/database.sqlite3"
-)  # aliased in settings.ini as "[database]name"
-DATABASE_USER = ""  # aliased in settings.ini as "[database]user"
-DATABASE_PASSWORD = ""  # aliased in settings.ini as "[database]password"
-DATABASE_HOST = ""  # aliased in settings.ini as "[database]host"
-DATABASE_PORT = ""  # aliased in settings.ini as "[database]port"
+DATABASE_URL = DatabaseURL("DATABASE_URL")
+DATABASE_ENGINE = DATABASE_URL.engine("django.db.backends.sqlite3")
+DATABASE_NAME = DATABASE_URL.database(Path("{LOCAL_PATH}/database.db"))
+DATABASE_USER = DATABASE_URL.username("")
+DATABASE_PASSWORD = DATABASE_URL.password("")
+DATABASE_HOST = DATABASE_URL.hostname("localhost")
+DATABASE_PORT = DATABASE_URL.port_int()
 DATABASE_OPTIONS = {}
-EMAIL_HOST = "localhost"  # aliased in settings.ini as "[email]host"
-EMAIL_HOST_PASSWORD = ""  # aliased in settings.ini as "[email]password"
-EMAIL_HOST_USER = ""  # aliased in settings.ini as "[email]user"
-EMAIL_FROM = "{ADMIN_EMAIL}"  # aliased in settings.ini as "[email]from"
-EMAIL_PORT = 25  # aliased in settings.ini as "[email]port"
+EMAIL_HOST_URL = URLSetting("EMAIL_HOST_URL")
+EMAIL_HOST = EMAIL_HOST_URL.hostname("localhost")
+EMAIL_HOST_PASSWORD = EMAIL_HOST_URL.password("")
+EMAIL_HOST_USER = EMAIL_HOST_URL.username("")
+EMAIL_FROM = "{ADMIN_EMAIL}"
+EMAIL_PORT = EMAIL_HOST_URL.port_int(25)
 EMAIL_SUBJECT_PREFIX = "[{SERVER_NAME}] "
-EMAIL_USE_TLS = False  # aliased in settings.ini as "[email]use_tls"
-EMAIL_USE_SSL = False  # aliased in settings.ini as "[email]use_ssl"
+EMAIL_USE_TLS = EMAIL_HOST_URL.use_tls()
+EMAIL_USE_SSL = EMAIL_HOST_URL.use_ssl()
 EMAIL_SSL_CERTFILE = None
 EMAIL_SSL_KEYFILE = None
 LANGUAGE_CODE = "en"  # aliased in settings.ini as "[global]language_code"
 TIME_ZONE = "Europe/Paris"  # aliased in settings.ini as "[global]time_zone"
-LOG_REMOTE_URL = None  # aliased in settings.ini as "[global]log_remote_url"
-LOG_LEVEL = None
-SERVER_BASE_URL = CallableSetting(
-    smart_hostname
-)  # aliased in settings.ini as "[global]server_url"
+SERVER_BASE_URL = CallableSetting(smart_base_url)
+HEROKU_APP_NAME = None  # used by HEROKU
 
 # df_config
-LISTEN_ADDRESS = DefaultListenAddress(
-    9000
-)  # aliased in settings.ini as "[global]listen_address"
-LOCAL_PATH = "./django_data"  # aliased in settings.ini as "[global]data"
+LISTEN_ADDRESS = CallableSetting(smart_listen_address)
+LISTEN_PORT = None  # listen port (if value is set, listen on 0.0.0.0)
+LOCAL_PATH = Path("./django_data")  # aliased in settings.ini as "[global]data"
 __split_path = __file__.split(os.path.sep)
 if "lib" in __split_path:
     prefix = os.path.join(*__split_path[: __split_path.index("lib")])
-    LOCAL_PATH = Directory("/%s/var/{DF_MODULE_NAME}" % prefix)
+    LOCAL_PATH = Path("/%s/var/{DF_MODULE_NAME}" % prefix)
 
+COMMON_REDIS_URL = RedisURL("COMMON_REDIS_URL")
+CURRENT_COMMAND_NAME = CallableSetting(get_command_name)
+HOSTNAME = CallableSetting(get_hostname)
 # django-redis-sessions
-SESSION_REDIS_PROTOCOL = "redis"
-SESSION_REDIS_HOST = "localhost"  # aliased in settings.ini as "[session]host"
-SESSION_REDIS_PORT = 6379  # aliased in settings.ini as "[session]port"
-SESSION_REDIS_DB = 1  # aliased in settings.ini as "[session]db"
-SESSION_REDIS_PASSWORD = None  # aliased in settings.ini as "[session]password"
+SESSION_REDIS_PROTOCOL = COMMON_REDIS_URL.scheme("redis")
+SESSION_REDIS_HOST = COMMON_REDIS_URL.hostname("localhost")
+SESSION_REDIS_PORT = COMMON_REDIS_URL.port_int(6379)
+SESSION_REDIS_DB = COMMON_REDIS_URL.database(1)
+SESSION_REDIS_PASSWORD = COMMON_REDIS_URL.password()
 
 # django_redis (cache)
-CACHE_PROTOCOL = "redis"
-CACHE_HOST = "localhost"  # aliased in settings.ini as "[cache]host"
-CACHE_PORT = 6379  # aliased in settings.ini as "[cache]port"
-CACHE_DB = 2  # aliased in settings.ini as "[cache]db"
-CACHE_PASSWORD = None  # aliased in settings.ini as "[cache]password"
+CACHE_PROTOCOL = COMMON_REDIS_URL.scheme("redis")
+CACHE_HOST = COMMON_REDIS_URL.hostname("localhost")
+CACHE_PORT = COMMON_REDIS_URL.port_int(6379)
+CACHE_DB = COMMON_REDIS_URL.database(2)
+CACHE_PASSWORD = COMMON_REDIS_URL.password()
 
 # celery
-CELERY_PROTOCOL = "redis"
-CELERY_HOST = "localhost"  # aliased in settings.ini as "[celery]host"
-CELERY_PORT = 6379  # aliased in settings.ini as "[celery]port"
-CELERY_DB = 4  # aliased in settings.ini as "[celery]db"
-CELERY_PASSWORD = None  # aliased in settings.ini as "[celery]password"
+CELERY_PROTOCOL = COMMON_REDIS_URL.scheme("redis")
+CELERY_HOST = COMMON_REDIS_URL.hostname("localhost")
+CELERY_PORT = COMMON_REDIS_URL.port_int(6379)
+CELERY_DB = COMMON_REDIS_URL.database(4)
+CELERY_PASSWORD = COMMON_REDIS_URL.password()
 CELERY_USERNAME = None  # only useful for amqp
 CELERY_PROCESSES = 4
 
-# celery
 CELERY_RESULT_PROTOCOL = SettingReference("CELERY_PROTOCOL")
 CELERY_RESULT_HOST = SettingReference("CELERY_HOST")
 CELERY_RESULT_PORT = SettingReference("CELERY_PORT")
@@ -556,11 +564,11 @@ CELERY_RESULT_PASSWORD = SettingReference("CELERY_PASSWORD")
 CELERY_RESULT_USERNAME = SettingReference("CELERY_USERNAME")
 
 # df_websockets
-WEBSOCKET_REDIS_PROTOCOL = "redis"
-WEBSOCKET_REDIS_HOST = "localhost"
-WEBSOCKET_REDIS_PORT = 6379
-WEBSOCKET_REDIS_DB = 1
-WEBSOCKET_REDIS_PASSWORD = None
+WEBSOCKET_REDIS_PROTOCOL = COMMON_REDIS_URL.scheme("redis")
+WEBSOCKET_REDIS_HOST = COMMON_REDIS_URL.hostname("localhost")
+WEBSOCKET_REDIS_PORT = COMMON_REDIS_URL.port_int(6379)
+WEBSOCKET_REDIS_DB = COMMON_REDIS_URL.database(1)
+WEBSOCKET_REDIS_PASSWORD = COMMON_REDIS_URL.password()
 
 # sentry.io
 USE_SENTRY = CallableSetting(use_sentry)
