@@ -13,67 +13,14 @@
 #  or https://cecill.info/licences/Licence_CeCILL-B_V1-fr.txt (French)         #
 #                                                                              #
 # ##############################################################################
-import os
-import re
 from urllib.parse import urlencode, urlparse
 
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.version import get_complete_version
-from pkg_resources import DistributionNotFound, get_distribution
 
-from df_config.checks import missing_package, settings_check_results
+from df_config.config.url import DatabaseURL
 from df_config.utils import is_package_present
 
-_default_database_engines = {
-    "mysql": "django.db.backends.mysql",
-    "mariadb": "django.db.backends.mysql",
-    "oracle": "django.db.backends.oracle",
-    "postgres": "django.db.backends.postgresql",
-    "postgresql": "django.db.backends.postgresql",
-    "sqlite": "django.db.backends.sqlite3",
-    "sqlite3": "django.db.backends.sqlite3",
-}
-
-
-def database_engine(settings_dict):
-    """Allow to use aliases for database engines, as well as the default dotted name"""
-    engine = _default_database_engines.get(
-        settings_dict["DATABASE_ENGINE"].lower(), settings_dict["DATABASE_ENGINE"]
-    )
-    if engine == "django.db.backends.postgresql":
-        try:
-            get_distribution("psycopg2-binary")
-        except DistributionNotFound:
-            try:
-                get_distribution("psycopg2")
-            except DistributionNotFound:
-                settings_check_results.append(
-                    missing_package("psycopg2-binary", " to use PostgreSQL database")
-                )
-    elif engine == "django.db.backends.oracle":
-        try:
-            get_distribution("cx_Oracle")
-        except DistributionNotFound:
-            settings_check_results.append(
-                missing_package("cx_Oracle", " to use Oracle database")
-            )
-    elif engine == "django.db.backends.mysql":
-        try:
-            get_distribution("mysqlclient")
-        except DistributionNotFound:
-            try:
-                get_distribution("pymysql")
-            except DistributionNotFound:
-                settings_check_results.append(
-                    missing_package(
-                        "mysqlclient or pymysql", " to use MySQL or MariaDB database"
-                    )
-                )
-    return engine
-
-
-database_engine.required_settings = ["DATABASE_ENGINE"]
-
 
 def databases(settings_dict):
     """Build a complete DATABASES setting.
@@ -81,32 +28,16 @@ def databases(settings_dict):
     If present, Takes the `DATABASE_URL` environment variable into account
     (used on the Heroku platform).
     """
-    engine = database_engine(settings_dict)
-    name = settings_dict["DATABASE_NAME"]
-    user = settings_dict["DATABASE_USER"]
-    options = settings_dict["DATABASE_OPTIONS"]
-    password = settings_dict["DATABASE_PASSWORD"]
-    host = settings_dict["DATABASE_HOST"]
-    port = settings_dict["DATABASE_PORT"]
-    if "DATABASE_URL" in os.environ:  # Used on Heroku environment
-        parsed = urlparse(os.environ["DATABASE_URL"])
-        engine = database_engine({"DATABASE_ENGINE": parsed.scheme})
-        user = parsed.username
-        name = parsed.path[1:]
-        password = parsed.password
-        host = parsed.hostname
-        port = parsed.port
-    return {
-        "default": {
-            "ENGINE": engine,
-            "NAME": name,
-            "USER": user,
-            "OPTIONS": options,
-            "PASSWORD": password,
-            "HOST": host,
-            "PORT": port,
-        }
+    default = {
+        "ENGINE": DatabaseURL.normalize_engine(settings_dict["DATABASE_ENGINE"]),
+        "NAME": settings_dict["DATABASE_NAME"],
+        "USER": settings_dict["DATABASE_USER"],
+        "OPTIONS": settings_dict["DATABASE_OPTIONS"],
+        "PASSWORD": settings_dict["DATABASE_PASSWORD"],
+        "HOST": settings_dict["DATABASE_HOST"],
+        "PORT": settings_dict["DATABASE_PORT"],
     }
+    return {"default": default}
 
 
 databases.required_settings = [
@@ -158,20 +89,8 @@ class RedisSmartSetting:
 
     def __call__(self, settings_dict):
         values = {x: settings_dict[self.prefix + x] for x in self.config_values}
-        values.setdefault("USERNAME", None)
+        values.setdefault("USERNAME")
         values["AUTH"] = ""
-        if (
-            values["PROTOCOL"] == "redis"
-            and self.env_variable
-            and self.env_variable in os.environ
-        ):
-            parsed_redis_url = urlparse(os.environ[self.env_variable])
-            values["HOST"] = parsed_redis_url.hostname
-            values["PORT"] = parsed_redis_url.port or 6379
-            values["PASSWORD"] = parsed_redis_url.password
-            values["DB"] = "0"
-            if re.match(r"^/\d+$", parsed_redis_url.path):
-                values["DB"] = parsed_redis_url.path[1:]
         if values["PASSWORD"]:
             values["AUTH"] = "%s:%s@" % (values["USERNAME"] or "", values["PASSWORD"])
         if self.fmt == "url":
@@ -242,25 +161,25 @@ def cache_setting(settings_dict):
     """
     parsed_url = urlparse(settings_dict["CACHE_URL"])
     django_version = get_complete_version()
+    default = {
+        "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
+        "LOCATION": "unique-snowflake",
+    }
     if settings_dict["DEBUG"]:
-        return {"default": {"BACKEND": "django.core.cache.backends.locmem.LocMemCache"}}
-    elif django_version >= (4, 0) and parsed_url.scheme == "redis":
+        pass
+    elif django_version >= (4, 0) and parsed_url.scheme in ("redis", "rediss"):
         # noinspection PyUnresolvedReferences
-        return {
-            "default": {
-                "BACKEND": "django.core.cache.backends.redis.RedisCache",
-                "LOCATION": "{CACHE_URL}",
-            }
+        default = {
+            "BACKEND": "django.core.cache.backends.redis.RedisCache",
+            "LOCATION": "{CACHE_URL}",
         }
-    elif parsed_url.scheme == "redis":
+    elif parsed_url.scheme in ("redis", "rediss"):
         if is_package_present("django_redis"):
             # noinspection PyUnresolvedReferences
-            return {
-                "default": {
-                    "BACKEND": "django_redis.cache.RedisCache",
-                    "LOCATION": "{CACHE_URL}",
-                    "OPTIONS": {"CLIENT_CLASS": "django_redis.client.DefaultClient"},
-                }
+            default = {
+                "BACKEND": "django_redis.cache.RedisCache",
+                "LOCATION": "{CACHE_URL}",
+                "OPTIONS": {"CLIENT_CLASS": "django_redis.client.DefaultClient"},
             }
     elif parsed_url.scheme == "memcache":
         if django_version >= (3, 2) and is_package_present("pymemcache"):
@@ -277,18 +196,11 @@ def cache_setting(settings_dict):
             parsed_url.hostname or "localhost",
             parsed_url.port or 11211,
         )
-        return {
-            "default": {
-                "BACKEND": backend,
-                "LOCATION": location,
-            }
+        default = {
+            "BACKEND": backend,
+            "LOCATION": location,
         }
-    return {
-        "default": {
-            "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
-            "LOCATION": "unique-snowflake",
-        }
-    }
+    return {"default": default}
 
 
 cache_setting.required_settings = ["DEBUG", "CACHE_URL"]
