@@ -14,6 +14,7 @@
 #                                                                              #
 # ##############################################################################
 import ipaddress
+import logging
 import os
 import re
 import sys
@@ -78,7 +79,6 @@ def get_merger_from_env() -> SettingMerger:
     if prefix == "/usr":
         prefix = ""
     ini_mapping = f"{module_name}.iniconf:INI_MAPPING"
-    environ_mapping = f"{module_name}.iniconf:ENVIRON_MAPPING"
     config_providers = [
         DictProvider({"DF_MODULE_NAME": module_name}, name="default values"),
         PythonModuleProvider("df_config.config.defaults"),
@@ -97,11 +97,13 @@ def get_merger_from_env() -> SettingMerger:
                 module_name,
             )
         ),
+        EnvironmentConfigProvider("%s_" % module_name.upper()),
         IniConfigProvider(os.path.abspath("local_settings.ini")),
         PythonFileProvider(os.path.abspath("local_settings.py")),
-        EnvironmentConfigProvider("%s_" % module_name.upper(), environ_mapping),
     ]
-    fields_provider = PythonConfigFieldsProvider(ini_mapping)
+    fields_provider = PythonConfigFieldsProvider(
+        ini_mapping, fallback="df_config.iniconf:DEFAULT_INI_MAPPING"
+    )
     return SettingMerger(fields_provider, config_providers)
 
 
@@ -113,7 +115,10 @@ def manage(argv=None):
     from django.core.management import execute_from_command_line
 
     patch_commands()
-    execute_from_command_line(argv=argv or sys.argv)
+    argv = argv or sys.argv
+    logger = logging.getLogger("django.server")
+    logger.info("command='%s'", " ".join(argv))
+    execute_from_command_line(argv=argv)
 
 
 def patch_commands():
